country_picker library
A flutter package to select a country from a list of countries.
Classes
- Country
- The country Model that has all the country information needed from the country_picker
- CountryListThemeData
- CountryLocalizations
- CountryParser
- Used to parse simple string representations of countries, commonly used in databases and other forms of storage, to a Country object.
- CountryService
Functions
-
showCountryPicker(
{required BuildContext context, required ValueChanged< Country> onSelect, VoidCallback? onClosed, List<String> ? favorite, List<String> ? exclude, List<String> ? countryFilter, bool showPhoneCode = false, CustomFlagBuilder? customFlagBuilder, CountryListThemeData? countryListTheme, bool searchAutofocus = false, bool showWorldWide = false, bool showSearch = true, bool showDragHandle = true, bool useSafeArea = false, bool moveAlongWithKeyboard = false, Widget header = const SizedBox.shrink()}) → void - Shows a bottom sheet containing a list of countries to select one.
Typedefs
- CustomFlagBuilder = Widget Function(Country country)